@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
 # Copyright 2015 Zuza Software Foundation
@@ -26,8 +25,8 @@ from translate.storage import po
 from translate.misc import wStringIO
 
 
-class TestPO2RESX:
-    XMLskeleton = '''<?xml version='1.0' encoding='utf-8'?>
+class TestPO2RESX(object):
+    XMLskeleton = '''<?xml version='1.0' encoding='UTF-8'?>
 <root>
   <xsd:schema xmlns="" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msdata="urn:schemas-microsoft-com:xml-msdata" id="root">
     <xsd:import namespace="http://www.w3.org/XML/1998/namespace"/>
@@ -87,11 +86,11 @@ class TestPO2RESX:
 
     def po2resx(self, resxsource, po_source):
         """ Helper that merges po translations to .resx source without requiring files """
-        po_store = po.pofile(po_source)
+        po_store = po.pofile(po_source.encode('utf-8'))
         template_file = wStringIO.StringIO(resxsource)
         convertor = po2resx.po2resx(template_file, po_store)
         output_resx = convertor.convertstore()
-        return output_resx
+        return output_resx.decode('utf-8')
 
     def test_simpleunit(self):
         """ Checks that a simple po entry definition converts properly to a resx entry """
@@ -99,11 +98,11 @@ class TestPO2RESX:
 msgid "Source Text"
 msgstr "Some translated text"'''
         resx_template = self.XMLskeleton % '''<data name="key" xml:space="preserve">
-        <value></value>
-        </data>'''
+    <value></value>
+  </data>'''
         expected_output = self.XMLskeleton % '''<data name="key" xml:space="preserve">
-        <value>Some translated text</value>
-    </data>'''
+    <value>Some translated text</value>
+  </data>'''
         resx_file = self.po2resx(resx_template, po_source)
         assert resx_file == expected_output
 
@@ -127,11 +126,11 @@ msgid "Applications"
 msgstr "Toepassings"
 """
         resx_template = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
-        <value></value>
-        </data>'''
+    <value></value>
+  </data>'''
         expected_output = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
-        <value>Toepassings</value>
-    </data>'''
+    <value>Toepassings</value>
+  </data>'''
         resx_file = self.po2resx(resx_template, po_source)
         assert resx_file == expected_output
 
@@ -143,11 +142,11 @@ msgid "First part "
 msgstr "Eerste deel "
 "en ekstra"'''
         resx_template = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
-        <value></value>
-        </data>'''
+    <value></value>
+  </data>'''
         expected_output = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
-        <value>Eerste deel en ekstra</value>
-    </data>'''
+    <value>Eerste deel en ekstra</value>
+  </data>'''
         resx_file = self.po2resx(resx_template, po_source)
         assert resx_file == expected_output
 
@@ -158,12 +157,12 @@ msgid "First line\nSecond line"
 msgstr "Eerste lyn\nTweede lyn"
 '''
         resx_template = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
-        <value></value>
-        </data>'''
+    <value></value>
+  </data>'''
         expected_output = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
-        <value>Eerste lyn
+    <value>Eerste lyn
 Tweede lyn</value>
-    </data>'''
+  </data>'''
         resx_file = self.po2resx(resx_template, po_source)
         assert resx_file == expected_output
 
@@ -174,11 +173,11 @@ msgid "First column\tSecond column"
 msgstr "Eerste kolom\tTweede kolom"
 '''
         resx_template = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
-        <value></value>
-        </data>'''
+    <value></value>
+  </data>'''
         expected_output = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
-        <value>Eerste kolom\tTweede kolom</value>
-    </data>'''
+    <value>Eerste kolom\tTweede kolom</value>
+  </data>'''
         resx_file = self.po2resx(resx_template, po_source)
         assert resx_file == expected_output
 
@@ -192,11 +191,11 @@ msgid "Use \\\"."
 msgstr "Gebruik \\\"."
 '''
         resx_template = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
-        <value></value>
-        </data>'''
+    <value></value>
+  </data>'''
         expected_output = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
-        <value>Good day "All"</value>
-    </data>'''
+    <value>Good day "All"</value>
+  </data>'''
         resx_file = self.po2resx(resx_template, po_source)
         assert resx_file == expected_output
 
@@ -216,223 +215,242 @@ msgid ""
 msgstr "Drie"
 '''
         resx_template = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
-        <value/>
-    </data>
-<data name="ResourceKey2" xml:space="preserve">
     <value/>
-</data>
-<data name="ResourceKey3" xml:space="preserve">
+  </data>
+  <data name="ResourceKey2" xml:space="preserve">
     <value/>
-</data>'''
+  </data>
+  <data name="ResourceKey3" xml:space="preserve">
+    <value/>
+  </data>'''
         expected_output = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
-        <value/>
-    </data>
-<data name="ResourceKey2" xml:space="preserve">
     <value/>
-</data>
-<data name="ResourceKey3" xml:space="preserve">
+  </data>
+  <data name="ResourceKey2" xml:space="preserve">
     <value/>
-</data>'''
+  </data>
+  <data name="ResourceKey3" xml:space="preserve">
+    <value/>
+  </data>'''
         resx_file = self.po2resx(resx_template, po_source)
         assert resx_file == expected_output
 
     def test_automaticcomments(self):
         """ Tests that automatic comments are imported """
-        po_source = r'''#. This is a comment
+        po_source = u'''#. This is a comment
 #: ResourceKey
 msgid "Bézier curve"
 msgstr "Bézier-kurwe"
 '''
         resx_template = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
-        <value></value>
-        </data>'''
-        expected_output = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
-        <value>Bézier-kurwe</value>
-    <comment>This is a comment</comment></data>'''
+    <value></value>
+  </data>'''
+        expected_output = self.XMLskeleton % u'''<data name="ResourceKey" xml:space="preserve">
+    <value>Bézier-kurwe</value>
+    <comment>This is a comment</comment>
+  </data>'''
         resx_file = self.po2resx(resx_template, po_source)
         assert resx_file == expected_output
 
     def test_automaticcomments_existingcomment(self):
         """ Tests a differing automatic comment is added if there is an existing automatic comment """
-        po_source = r'''#. This is a new comment
+        po_source = u'''#. This is a new comment
 #: ResourceKey
 msgid "Bézier curve"
 msgstr "Bézier-kurwe"
 '''
         resx_template = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
-        <value></value>
-        <comment>This is an existing comment</comment></data>'''
-        expected_output = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
-        <value>Bézier-kurwe</value>
+    <value></value>
+    <comment>This is an existing comment</comment>
+  </data>'''
+        expected_output = self.XMLskeleton % u'''<data name="ResourceKey" xml:space="preserve">
+    <value>Bézier-kurwe</value>
     <comment>This is an existing comment
-This is a new comment</comment></data>'''
+This is a new comment</comment>
+  </data>'''
         resx_file = self.po2resx(resx_template, po_source)
         assert resx_file == expected_output
 
     def test_automaticcomments_existingduplicatecomment(self):
         """ Tests there is no duplication of automatic comments if it already exists and hasn't changed """
-        po_source = r'''#. This is an existing comment
+        po_source = u'''#. This is an existing comment
 #: ResourceKey
 msgid "Bézier curve"
 msgstr "Bézier-kurwe"
 '''
         resx_template = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
-        <value></value>
-        <comment>This is an existing comment</comment></data>'''
-        expected_output = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
-        <value>Bézier-kurwe</value>
-    <comment>This is an existing comment</comment></data>'''
+    <value></value>
+    <comment>This is an existing comment</comment>
+  </data>'''
+        expected_output = self.XMLskeleton % u'''<data name="ResourceKey" xml:space="preserve">
+    <value>Bézier-kurwe</value>
+    <comment>This is an existing comment</comment>
+  </data>'''
         resx_file = self.po2resx(resx_template, po_source)
         assert resx_file == expected_output
 
     def test_automaticcomments_existingduplicatecommentwithwhitespace(self):
         """ Tests there is no duplication of automatic comments if it already exists, hasn't changed but has leading or
         trailing whitespaces """
-        po_source = r'''#.  This is an existing comment with leading and trailing spaces
+        po_source = u'''#.  This is an existing comment with leading and trailing spaces
 #: ResourceKey
 msgid "Bézier curve"
 msgstr "Bézier-kurwe"
 '''
         resx_template = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
-        <value></value>
-        <comment> This is an existing comment with leading and trailing spaces </comment></data>'''
-        expected_output = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
-        <value>Bézier-kurwe</value>
-    <comment>This is an existing comment with leading and trailing spaces</comment></data>'''
+    <value></value>
+    <comment> This is an existing comment with leading and trailing spaces </comment>
+  </data>'''
+        expected_output = self.XMLskeleton % u'''<data name="ResourceKey" xml:space="preserve">
+    <value>Bézier-kurwe</value>
+    <comment>This is an existing comment with leading and trailing spaces</comment>
+  </data>'''
         resx_file = self.po2resx(resx_template, po_source)
         assert resx_file == expected_output
 
     def test_translatorcomments(self):
         """ Tests that translator comments are imported """
-        po_source = r'''# This is a translator comment : 22.12.14
+        po_source = u'''# This is a translator comment : 22.12.14
 #: ResourceKey
 msgid "Bézier curve"
 msgstr "Bézier-kurwe"
 '''
         resx_template = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
-        <value></value>
-        </data>'''
-        expected_output = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
-        <value>Bézier-kurwe</value>
-    <comment>[Translator Comment: This is a translator comment : 22.12.14]</comment></data>'''
+    <value></value>
+  </data>'''
+        expected_output = self.XMLskeleton % u'''<data name="ResourceKey" xml:space="preserve">
+    <value>Bézier-kurwe</value>
+    <comment>[Translator Comment: This is a translator comment : 22.12.14]</comment>
+  </data>'''
         resx_file = self.po2resx(resx_template, po_source)
         assert resx_file == expected_output
 
     def test_translatorcomments_existingcomment(self):
         """ Tests a differing translator comment is added if there is an existing translator comment """
-        po_source = r'''# This is a new translator comment
+        po_source = u'''# This is a new translator comment
 #: ResourceKey
 msgid "Bézier curve"
 msgstr "Bézier-kurwe"
 '''
         resx_template = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
-        <value></value>
-        <comment>[Translator Comment: This is an existing comment]</comment></data>'''
-        expected_output = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
-        <value>Bézier-kurwe</value>
+    <value></value>
+    <comment>[Translator Comment: This is an existing comment]</comment>
+  </data>'''
+        expected_output = self.XMLskeleton % u'''<data name="ResourceKey" xml:space="preserve">
+    <value>Bézier-kurwe</value>
     <comment>[Translator Comment: This is an existing comment]
-[Translator Comment: This is a new translator comment]</comment></data>'''
+[Translator Comment: This is a new translator comment]</comment>
+  </data>'''
         resx_file = self.po2resx(resx_template, po_source)
         assert resx_file == expected_output
 
     def test_translatorcomments_existingduplicatecomment(self):
         """ Tests there is no duplication of translator comments if it already exists and hasn't changed """
-        po_source = r'''# This is an existing translator comment
+        po_source = u'''# This is an existing translator comment
 #: ResourceKey
 msgid "Bézier curve"
 msgstr "Bézier-kurwe"
 '''
         resx_template = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
-        <value></value>
-        <comment>[Translator Comment: This is an existing translator comment]</comment></data>'''
-        expected_output = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
-        <value>Bézier-kurwe</value>
-    <comment>[Translator Comment: This is an existing translator comment]</comment></data>'''
+    <value></value>
+    <comment>[Translator Comment: This is an existing translator comment]</comment>
+  </data>'''
+        expected_output = self.XMLskeleton % u'''<data name="ResourceKey" xml:space="preserve">
+    <value>Bézier-kurwe</value>
+    <comment>[Translator Comment: This is an existing translator comment]</comment>
+  </data>'''
         resx_file = self.po2resx(resx_template, po_source)
         assert resx_file == expected_output
 
     def test_combocomments(self):
         """ Tests that translator comments and automatic comments are imported """
-        po_source = r'''#. This is a developer comment
+        po_source = u'''#. This is a developer comment
 # This is a translator comment : 22.12.14
 #: ResourceKey
 msgid "Bézier curve"
 msgstr "Bézier-kurwe"
 '''
         resx_template = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
-        <value></value>
-        </data>'''
-        expected_output = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
-        <value>Bézier-kurwe</value>
+    <value></value>
+  </data>'''
+        expected_output = self.XMLskeleton % u'''<data name="ResourceKey" xml:space="preserve">
+    <value>Bézier-kurwe</value>
     <comment>This is a developer comment
-[Translator Comment: This is a translator comment : 22.12.14]</comment></data>'''
+[Translator Comment: This is a translator comment : 22.12.14]</comment>
+  </data>'''
         resx_file = self.po2resx(resx_template, po_source)
         assert resx_file == expected_output
 
     def test_combocomments_existingduplicatecomment(self):
         """ Tests there is no duplication of automatic comment if it already exists and hasn't changed, but still adds
         the translator comment """
-        po_source = r'''#. This is an existing comment
+        po_source = u'''#. This is an existing comment
 # This is a translator comment : 22.12.14
 #: ResourceKey
 msgid "Bézier curve"
 msgstr "Bézier-kurwe"
 '''
         resx_template = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
-        <value></value>
-        <comment>This is an existing comment</comment></data>'''
-        expected_output = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
-        <value>Bézier-kurwe</value>
+    <value></value>
+    <comment>This is an existing comment</comment>
+  </data>'''
+        expected_output = self.XMLskeleton % u'''<data name="ResourceKey" xml:space="preserve">
+    <value>Bézier-kurwe</value>
     <comment>This is an existing comment
-[Translator Comment: This is a translator comment : 22.12.14]</comment></data>'''
+[Translator Comment: This is a translator comment : 22.12.14]</comment>
+  </data>'''
         resx_file = self.po2resx(resx_template, po_source)
         assert resx_file == expected_output
 
     def test_combocomments_existingcomment(self):
         """ Tests a differing automatic comment is added if there is an existing automatic comment, but still adds
         the translator comment """
-        po_source = r'''#. This is a new comment
+        po_source = u'''#. This is a new comment
 # This is a translator comment : 22.12.14
 #: ResourceKey
 msgid "Bézier curve"
 msgstr "Bézier-kurwe"
 '''
         resx_template = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
-        <value></value>
-        <comment>This is an existing comment</comment></data>'''
-        expected_output = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
-        <value>Bézier-kurwe</value>
+    <value></value>
+    <comment>This is an existing comment</comment>
+  </data>'''
+        expected_output = self.XMLskeleton % u'''<data name="ResourceKey" xml:space="preserve">
+    <value>Bézier-kurwe</value>
     <comment>This is an existing comment
 This is a new comment
-[Translator Comment: This is a translator comment : 22.12.14]</comment></data>'''
+[Translator Comment: This is a translator comment : 22.12.14]</comment>
+  </data>'''
         resx_file = self.po2resx(resx_template, po_source)
         assert resx_file == expected_output
 
     def test_existingcomments(self):
         """ Tests that no extra space is added when there are no changes to existing comments"""
-        po_source = r'''#. This is an existing comment
+        po_source = u'''#. This is an existing comment
 # This is an existing translator comment : 22.12.14
 #: ResourceKey
 msgid "Bézier curve"
 msgstr "Bézier-kurwe"
 '''
         resx_template = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
-        <value></value>
-        <comment>This is an existing comment
-[Translator Comment: This is an existing translator comment : 22.12.14]</comment></data>'''
-        expected_output = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
-        <value>Bézier-kurwe</value>
+    <value></value>
     <comment>This is an existing comment
-[Translator Comment: This is an existing translator comment : 22.12.14]</comment></data>'''
+[Translator Comment: This is an existing translator comment : 22.12.14]</comment>
+  </data>'''
+        expected_output = self.XMLskeleton % u'''<data name="ResourceKey" xml:space="preserve">
+    <value>Bézier-kurwe</value>
+    <comment>This is an existing comment
+[Translator Comment: This is an existing translator comment : 22.12.14]</comment>
+  </data>'''
         resx_file = self.po2resx(resx_template, po_source)
         assert resx_file == expected_output
 
 
-class TestPO2TSCommand(test_convert.TestConvertCommand, TestPO2RESX):
-    """ Tests running actual po2ts commands on files """
+class TestPO2RESXCommand(test_convert.TestConvertCommand, TestPO2RESX):
+    """ Tests running actual po2resx commands on files """
     convertmodule = po2resx
 
-    def test_help(self):
+    def test_help(self, capsys):
         """ Tests getting help """
-        options = test_convert.TestConvertCommand.test_help(self)
+        options = test_convert.TestConvertCommand.test_help(self, capsys)
         options = self.help_check(options, "-t TEMPLATE, --template=TEMPLATE")
