@@ -18,8 +18,8 @@ class TestPO2Sub(object):
         files"""
         inputfile = wStringIO.StringIO(posource)
         inputpo = po.pofile(inputfile)
-        convertor = po2sub.resub()
-        outputsub = convertor.convertstore(inputpo)
+        convertor = po2sub.po2sub()
+        outputsub = convertor.convert_store(inputpo)
         return outputsub.decode('utf-8')
 
     def merge2sub(self, subsource, posource):
@@ -28,8 +28,8 @@ class TestPO2Sub(object):
         inputfile = wStringIO.StringIO(posource)
         inputpo = po.pofile(inputfile)
         templatefile = wStringIO.StringIO(subsource)
-        convertor = po2sub.resub(templatefile, inputpo)
-        outputsub = convertor.convertstore()
+        convertor = po2sub.po2sub(templatefile, inputpo)
+        outputsub = convertor.convert_store()
         print(outputsub)
         return outputsub.decode('utf-8')
 
@@ -69,9 +69,9 @@ class TestPO2SubCommand(test_convert.TestConvertCommand, TestPO2Sub):
     convertmodule = po2sub
     defaultoptions = {"progress": "none"}
 
-    def test_help(self):
+    def test_help(self, capsys):
         """tests getting help"""
-        options = test_convert.TestConvertCommand.test_help(self)
+        options = test_convert.TestConvertCommand.test_help(self, capsys)
         options = self.help_check(options, "-t TEMPLATE, --template=TEMPLATE")
         options = self.help_check(options, "--threshold=PERCENT")
         options = self.help_check(options, "--fuzzy")
