@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
 # Copyright 2007 Zuza Software Foundation
@@ -23,6 +22,8 @@
 .. seealso:: http://en.wikipedia.org/wiki/Thai_language
 """
 
+from __future__ import unicode_literals
+
 from translate.lang import common
 
 
@@ -30,10 +31,12 @@ class th(common.Common):
     """This class represents Thai."""
 
     puncdict = {
-        u". ": u" ",
-        #u"; ": u" ", # Test interaction with XML entities
+        ". ": " ",
+        #"; ": " ", # Test interaction with XML entities
     }
 
     # No capitalisation. While we can't do sentence segmentation, sentencecount
     # is useless.
-    ignoretests = ["startcaps", "simplecaps", "sentencecount"]
+    ignoretests = {
+        'all': ["sentencecount", "simplecaps", "startcaps"],
+    }
