@@ -34,6 +34,7 @@ import re
 import six
 
 from translate.lang import data
+from translate.misc.deprecation import deprecated
 from translate.misc.multistring import multistring
 from translate.storage import base, cpo, pocommon
 
@@ -85,46 +86,54 @@ class pounit(pocommon.pounit):
             self.typecomments = []
             self.msgidcomment = u""
 
-    def getsource(self):
+    @property
+    def source(self):
         return self._source
 
-    def setsource(self, source):
+    @source.setter
+    def source(self, source):
         self._rich_source = None
-#        assert isinstance(source, unicode)
         source = data.forceunicode(source or u"")
         source = source or u""
         if isinstance(source, multistring):
             self._source = source
         elif isinstance(source, six.text_type):
             self._source = source
-        else:
-            #unicode, list, dict
+        else:  # If it is unicode, list or dict.
             self._source = multistring(source)
-    source = property(getsource, setsource)
 
-    def gettarget(self):
+    # Deprecated on 2.3.1
+    @deprecated("Use `source` property instead")
+    def getsource(self):
+        return self.source
+
+    @property
+    def target(self):
         """Returns the unescaped msgstr"""
         return self._target
 
-    def settarget(self, target):
+    @target.setter
+    def target(self, target):
         """Sets the msgstr to the given (unescaped) value"""
         self._rich_target = None
-#        assert isinstance(target, unicode)
-#        target = data.forceunicode(target)
         if self.hasplural():
             if isinstance(target, multistring):
                 self._target = target
-            else:
-                #unicode, list, dict
+            else:  # If it is unicode, list or dict.
                 self._target = multistring(target)
         elif isinstance(target, (dict, list)):
             if len(target) == 1:
                 self._target = target[0]
             else:
-                raise ValueError("po msgid element has no plural but msgstr has %d elements (%s)" % (len(target), target))
+                raise ValueError("po msgid element has no plural but msgstr"
+                                 "has %d elements (%s)" % (len(target), target))
         else:
             self._target = target
-    target = property(gettarget, settarget)
+
+    # Deprecated on 2.3.1
+    @deprecated("Use `target` property instead")
+    def gettarget(self):
+        return self.target
 
     def getnotes(self, origin=None):
         """Return comments based on origin value (programmer, developer, source code and translator)"""
