@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
 # Copyright 2009 Zuza Software Foundation
@@ -38,10 +37,16 @@ Encoding
     encoded files use the .utf8 extension while system encoded files use
     the .tab extension.
 """
+from __future__ import unicode_literals
 
-import csv
 import locale
+import six
+if six.PY2:
+    from backports import csv
+else:
+    import csv
 
+from translate.misc.deprecation import deprecated
 from translate.storage import base
 
 
@@ -51,13 +56,18 @@ OMEGAT_FIELDNAMES = ["source", "target", "comment"]
 
 class OmegaTDialect(csv.Dialect):
     """Describe the properties of an OmegaT generated TAB-delimited glossary
-    file."""
+    file.
+    """
+
     delimiter = "\t"
     lineterminator = "\r\n"
     quoting = csv.QUOTE_NONE
+
+
 csv.register_dialect("omegat", OmegaTDialect)
 
 
+@six.python_2_unicode_compatible
 class OmegaTUnit(base.TranslationUnit):
     """An OmegaT glossary unit"""
 
@@ -85,16 +95,14 @@ class OmegaTUnit(base.TranslationUnit):
         if key not in self._dict:
             return None
         elif self._dict[key]:
-            return self._dict[key].decode('utf-8')
+            return self._dict[key]
         else:
             return ""
 
     def _set_field(self, key, newvalue):
         if newvalue is None:
             self._dict[key] = None
-        if isinstance(newvalue, unicode):
-            newvalue = newvalue.encode('utf-8')
-        if not key in self._dict or newvalue != self._dict[key]:
+        if key not in self._dict or newvalue != self._dict[key]:
             self._dict[key] = newvalue
 
     def getnotes(self, origin=None):
@@ -110,21 +118,33 @@ class OmegaTUnit(base.TranslationUnit):
     def removenotes(self):
         self._set_field('comment', u'')
 
-    def getsource(self):
+    @property
+    def source(self):
         return self._get_field('source')
 
-    def setsource(self, newsource):
+    @source.setter
+    def source(self, source):
         self._rich_source = None
-        return self._set_field('source', newsource)
-    source = property(getsource, setsource)
+        self._set_field('source', source)
 
-    def gettarget(self):
+    # Deprecated on 2.3.1
+    @deprecated("Use `source` property instead")
+    def getsource(self):
+        return self.source
+
+    @property
+    def target(self):
         return self._get_field('target')
 
-    def settarget(self, newtarget):
+    @target.setter
+    def target(self, target):
         self._rich_target = None
-        return self._set_field('target', newtarget)
-    target = property(gettarget, settarget)
+        self._set_field('target', target)
+
+    # Deprecated on 2.3.1
+    @deprecated("Use `target` property instead")
+    def gettarget(self):
+        return self.target
 
     def settargetlang(self, newlang):
         self._dict['target-lang'] = newlang
@@ -139,24 +159,21 @@ class OmegaTUnit(base.TranslationUnit):
 
 class OmegaTFile(base.TranslationStore):
     """An OmegaT glossary file"""
+
     Name = "OmegaT Glossary"
     Mimetypes = ["application/x-omegat-glossary"]
     Extensions = ["utf8"]
+    UnitClass = OmegaTUnit
 
-    def __init__(self, inputfile=None, unitclass=OmegaTUnit):
-        """Construct an OmegaT glossary, optionally reading in from
-        inputfile."""
-        self.UnitClass = unitclass
-        base.TranslationStore.__init__(self, unitclass=unitclass)
+    def __init__(self, inputfile=None, **kwargs):
+        """Construct an OmegaT glossary, optionally reading in from inputfile.
+        """
+        super(OmegaTFile, self).__init__(**kwargs)
         self.filename = ''
         self.extension = ''
-        self._encoding = self._get_encoding()
         if inputfile is not None:
             self.parse(inputfile)
 
-    def _get_encoding(self):
-        return 'utf-8'
-
     def parse(self, input):
         """parsese the given file or file source string"""
         if hasattr(input, 'name'):
@@ -168,8 +185,8 @@ class OmegaTFile(base.TranslationStore):
             input.close()
             input = tmsrc
         try:
-            input = input.decode(self._encoding).encode('utf-8')
-        except:
+            input = input.decode(self.encoding)
+        except Exception:
             raise ValueError("OmegaT files are either UTF-8 encoded or use the default system encoding")
         lines = csv.DictReader(input.split("\n"), fieldnames=OMEGAT_FIELDNAMES,
                                dialect="omegat")
@@ -178,30 +195,26 @@ class OmegaTFile(base.TranslationStore):
             newunit.dict = line
             self.addunit(newunit)
 
-    def __str__(self):
+    def serialize(self, out):
+        # Check first if there is at least one translated unit
+        translated_units = [u for u in self.units if u.istranslated()]
+        if not translated_units:
+            return
+
         output = csv.StringIO()
-        writer = csv.DictWriter(output, fieldnames=OMEGAT_FIELDNAMES,
-                                dialect="omegat")
-        unit_count = 0
-        for unit in self.units:
-            if unit.istranslated():
-                unit_count += 1
-                writer.writerow(unit.dict)
-        if unit_count == 0:
-            return ""
-        output.reset()
-        decoded = "".join(output.readlines()).decode('utf-8')
-        try:
-            return decoded.encode(self._encoding)
-        except UnicodeEncodeError:
-            return decoded.encode('utf-8')
+        writer = csv.DictWriter(output, fieldnames=OMEGAT_FIELDNAMES, dialect="omegat")
+        for unit in translated_units:
+            writer.writerow(unit.dict)
+        out.write(output.getvalue().encode(self.encoding))
 
 
 class OmegaTFileTab(OmegaTFile):
     """An OmegaT glossary file in the default system encoding"""
+
     Name = "OmegaT Glossary"
     Mimetypes = ["application/x-omegat-glossary"]
     Extensions = ["tab"]
 
-    def _get_encoding(self):
+    @property
+    def encoding(self):
         return locale.getdefaultlocale()[1]
