@@ -125,6 +125,7 @@ from codecs import iterencode
 
 from translate.lang import data
 from translate.misc import quote
+from translate.misc.deprecation import deprecated
 from translate.storage import base
 
 
@@ -176,7 +177,7 @@ def is_comment_one_line(line):
     :rtype: bool
     """
     stripped = line.strip()
-    line_starters = (u'#', u'!', u'//', )
+    line_starters = (u'#', u'!', u'//', u';')
     for starter in line_starters:
         if stripped.startswith(starter):
             return True
@@ -258,6 +259,10 @@ class Dialect(object):
             return quote.javapropertiesencode(string or u"")
         return quote.java_utf8_properties_encode(string or u"")
 
+    @staticmethod
+    def decode(string):
+        return quote.propertiesdecode(string)
+
     @classmethod
     def find_delimiter(cls, line):
         """Find the type and position of the delimiter in a property line.
@@ -323,6 +328,14 @@ class Dialect(object):
         """Strip unneeded characters from the value"""
         return value.lstrip()
 
+    @classmethod
+    def is_line_continuation(cls, line):
+        return is_line_continuation(line)
+
+    @classmethod
+    def strip_line_continuation(cls, value):
+        return value[:-1]
+
 
 @register_dialect
 class DialectJava(Dialect):
@@ -414,6 +427,17 @@ class DialectStrings(Dialect):
     def encode(cls, string, encoding=None):
         return string.replace("\n", r"\n").replace("\t", r"\t")
 
+    @classmethod
+    def is_line_continuation(self, line):
+        l = line.rstrip()
+        if l and l[-1] == ';':
+            return False
+        return True
+
+    @classmethod
+    def strip_line_continuation(cls, value):
+        return value
+
 
 @register_dialect
 class DialectStringsUtf8(DialectStrings):
@@ -421,6 +445,35 @@ class DialectStringsUtf8(DialectStrings):
     default_encoding = "utf-8"
 
 
+@register_dialect
+class DialectJoomla(Dialect):
+    name = "joomla"
+    default_encoding = "utf-8"
+    delimiters = [u"="]
+    out_delimiter_wrappers = u''
+
+    @classmethod
+    def value_strip(cls, value):
+        """Strip unneeded characters from the value"""
+        newvalue = value.strip()
+        if not newvalue:
+            return newvalue
+        if newvalue[0] == '"' and newvalue[-1] == '"':
+            newvalue = newvalue[1:-1]
+        return newvalue.replace('"_QQ_"', '"')
+
+    @classmethod
+    def decode(cls, string):
+        return cls.value_strip(string)
+
+    @classmethod
+    def encode(cls, string, encoding=None):
+        """Encode the string"""
+        if not string:
+            return string
+        return '"%s"' % string.replace("\n", r"\n").replace("\t", r"\t").replace('"', '"_QQ_"')
+
+
 @six.python_2_unicode_compatible
 class propunit(base.TranslationUnit):
     """An element of a properties file i.e. a name and value, and any comments
@@ -445,29 +498,36 @@ class propunit(base.TranslationUnit):
         # (e.g. ";" is required for Mac OS X strings)
         self.out_ending = getattr(self.personality, 'out_ending', u'')
 
-    def getsource(self):
-        value = quote.propertiesdecode(self.value)
-        return value
+    @property
+    def source(self):
+        return self.personality.decode(self.value)
 
-    def setsource(self, source):
+    @source.setter
+    def source(self, source):
         self._rich_source = None
-        source = data.forceunicode(source)
-        self.value = self.personality.encode(source or u"", self.encoding)
+        self.value = self.personality.encode(data.forceunicode(source) or u"",
+                                             self.encoding)
 
-    source = property(getsource, setsource)
+    # Deprecated on 2.3.1
+    @deprecated("Use `source` property instead")
+    def getsource(self):
+        return self.source
 
-    def gettarget(self):
-        translation = quote.propertiesdecode(self.translation)
-        translation = re.sub(u"\\\\ ", u" ", translation)
-        return translation
+    @property
+    def target(self):
+        return re.sub(u"\\\\ ", u" ", self.personality.decode(self.translation))
 
-    def settarget(self, target):
+    @target.setter
+    def target(self, target):
         self._rich_target = None
         target = data.forceunicode(target)
         self.translation = self.personality.encode(target or u"",
                                                    self.encoding)
 
-    target = property(gettarget, settarget)
+    # Deprecated on 2.3.1
+    @deprecated("Use `target` property instead")
+    def gettarget(self):
+        return self.target
 
     @property
     def encoding(self):
@@ -590,13 +650,15 @@ class propfile(base.TranslationStore):
             if inmultilinevalue:
                 newunit.value += line.lstrip()
                 # see if there's more
-                inmultilinevalue = is_line_continuation(newunit.value)
+                inmultilinevalue = self.personality.is_line_continuation(
+                    newunit.value)
                 # if we're still waiting for more...
                 if inmultilinevalue:
-                    # strip the backslash
-                    newunit.value = newunit.value[:-1]
+                    newunit.value = self.personality.strip_line_continuation(
+                        newunit.value)
                 if not inmultilinevalue:
                     # we're finished, add it to the list...
+                    newunit.value = self.personality.value_strip(newunit.value)
                     self.addunit(newunit)
                     newunit = propunit("", self.personality.name)
             # otherwise, this could be a comment
@@ -620,13 +682,17 @@ class propfile(base.TranslationStore):
                 if delimiter_pos == -1:
                     newunit.name = self.personality.key_strip(line)
                     newunit.value = u""
+                    newunit.delimiter = u""
                     self.addunit(newunit)
                     newunit = propunit("", self.personality.name)
                 else:
                     newunit.name = self.personality.key_strip(line[:delimiter_pos])
-                    if is_line_continuation(line[delimiter_pos+1:].lstrip()):
+                    if self.personality.is_line_continuation(
+                            line[delimiter_pos+1:].lstrip()):
                         inmultilinevalue = True
                         newunit.value = line[delimiter_pos+1:].lstrip()[:-1]
+                        newunit.value = self.personality.strip_line_continuation(
+                            line[delimiter_pos+1:].lstrip())
                     else:
                         newunit.value = self.personality.value_strip(line[delimiter_pos+1:])
                         self.addunit(newunit)
@@ -671,7 +737,7 @@ class stringsfile(propfile):
         super(stringsfile, self).__init__(*args, **kwargs)
 
 
-class stringsutf8file(propfile):
+class stringsutf8file(stringsfile):
     Name = "OS X Strings (UTF-8)"
     Extensions = ['strings']
 
@@ -679,3 +745,12 @@ class stringsutf8file(propfile):
         kwargs['personality'] = "strings-utf8"
         kwargs['encoding'] = "utf-8"
         super(stringsutf8file, self).__init__(*args, **kwargs)
+
+
+class joomlafile(propfile):
+    Name = "Joomla Translations"
+    Extensions = ['ini']
+
+    def __init__(self, *args, **kwargs):
+        kwargs['personality'] = "joomla"
+        super(joomlafile, self).__init__(*args, **kwargs)
