@@ -48,6 +48,29 @@ po_unescape_map = {"\\r": "\r", "\\t": "\t", '\\"': '"', '\\n': '\n', '\\\\': '\
 po_escape_map = dict([(value, key) for (key, value) in po_unescape_map.items()])
 
 
+def splitlines(text):
+    """Split lines based on first newline char.
+
+    Can not use univerzal newlines as they match any newline like
+    character inside text and that breaks on files with unix newlines
+    and LF chars inside comments.
+    """
+    # Find first newline
+    newline = b'\n'
+    for i, ch in enumerate(text):
+        # Iteration over bytes yields numbers in Python 3
+        if ch in ('\n', 10):
+            break
+        if ch in ('\r', 13):
+            if text[i + 1] in ('\n', 10):
+                newline = b'\r\n'
+            else:
+                newline = b'\r'
+            break
+
+    return [x + newline for x in text.split(newline)]
+
+
 def escapeforpo(line):
     """Escapes a line for po format. assumes no \n occurs in the line.
 
@@ -76,6 +99,7 @@ wrapper = textwrap.TextWrapper(
     drop_whitespace=False)
 wrapper.wordsep_re = re.compile(
     r'(\s+|'                                  # any whitespace
+    r'[a-z0-9A-Z_-]+/|'                       # nicely split long URLs
     r'\w*\\.|'                                # any escape should not be split
     r'[\w\!\'\&\.\,\?]+\s+|'                  # space should go with a word
     r'[^\s\w]*\w+[a-zA-Z]-(?=\w+[a-zA-Z])|'   # hyphenated words
@@ -83,22 +107,26 @@ wrapper.wordsep_re = re.compile(
 wrapper.wordsep_re_uni = re.compile(wrapper.wordsep_re.pattern, re.UNICODE)
 
 
-def quoteforpo(text):
+def quoteforpo(text, wrapper_obj=None):
     """Quotes the given text for a PO file, returning quoted and escaped lines
     """
     if text is None:
         return []
+    if wrapper_obj is None:
+        wrapper_obj = wrapper
     text = escapeforpo(text)
+    if wrapper_obj.width == -1:
+        return [u'"%s"' % text]
     lines = text.split(u"\\n")
     for i, l in enumerate(lines[:-1]):
         lines[i] = l + u"\\n"
 
     polines = []
     len_lines = len(lines)
-    if len_lines > 2 or (len_lines == 2 and lines[1]) or len(lines[0]) > 71:
+    if len_lines > 2 or (len_lines == 2 and lines[1]) or len(lines[0]) > wrapper_obj.width - 6:
         polines.append(u'""')
     for line in lines:
-        lns = wrapper.wrap(line)
+        lns = wrapper_obj.wrap(line)
         for ln in lns:
             polines.append(u'"%s"' % ln)
     return polines
@@ -184,9 +212,10 @@ class pounit(pocommon.pounit):
 
     # Our homegrown way to indicate what must be copied in a shallow
     # fashion
-    __shallow__ = ['_store']
+    __shallow__ = ['_store', 'wrapper']
 
-    def __init__(self, source=None, **kwargs):
+    def __init__(self, source=None, wrapper=None, **kwargs):
+        self.wrapper = wrapper
         self.obsolete = False
         self._initallcomments(blankall=True)
         self.prev_msgctxt = []
@@ -225,6 +254,9 @@ class pounit(pocommon.pounit):
             return multistring([singular, pluralform])
         return singular
 
+    def quote(self, text):
+        return quoteforpo(text, self.wrapper)
+
     def _set_source_vars(self, source):
         msgid = None
         msgid_plural = None
@@ -234,28 +266,34 @@ class pounit(pocommon.pounit):
         if isinstance(source, multistring):
             source = source.strings
         if isinstance(source, list):
-            msgid = quoteforpo(source[0])
+            msgid = self.quote(source[0])
             if len(source) > 1:
-                msgid_plural = quoteforpo(source[1])
+                msgid_plural = self.quote(source[1])
             else:
                 msgid_plural = []
         else:
-            msgid = quoteforpo(source)
+            msgid = self.quote(source)
             msgid_plural = []
         return msgid, msgid_plural
 
-    def getsource(self):
+    @property
+    def source(self):
         """Returns the unescaped msgid"""
         return self._get_source_vars(self.msgid, self.msgid_plural)
 
-    def setsource(self, source):
+    @source.setter
+    def source(self, source):
         """Sets the msgid to the given (unescaped) value.
 
         :param source: an unescaped source string.
         """
         self._rich_source = None
         self.msgid, self.msgid_plural = self._set_source_vars(source)
-    source = property(getsource, setsource)
+
+    # Deprecated on 2.3.1
+    @deprecated("Use `source` property instead")
+    def getsource(self):
+        return self.source
 
     def _get_prev_source(self):
         """Returns the unescaped msgid"""
@@ -269,14 +307,16 @@ class pounit(pocommon.pounit):
         self.prev_msgid, self.prev_msgid_plural = self._set_source_vars(source)
     prev_source = property(_get_prev_source, _set_prev_source)
 
-    def gettarget(self):
+    @property
+    def target(self):
         """Returns the unescaped msgstr"""
         if isinstance(self.msgstr, dict):
             return multistring(list(map(unquotefrompo, self.msgstr.values())))
         else:
             return unquotefrompo(self.msgstr)
 
-    def settarget(self, target):
+    @target.setter
+    def target(self, target):
         """Sets the msgstr to the given (unescaped) value"""
         self._rich_target = None
         if isinstance(target, bytes):
@@ -296,12 +336,16 @@ class pounit(pocommon.pounit):
         if isinstance(templates, list):
             templates = {0: templates}
         if isinstance(target, list):
-            self.msgstr = dict([(i, quoteforpo(target[i])) for i in range(len(target))])
+            self.msgstr = dict([(i, self.quote(target[i])) for i in range(len(target))])
         elif isinstance(target, dict):
-            self.msgstr = dict([(i, quoteforpo(targetstring)) for i, targetstring in six.iteritems(target)])
+            self.msgstr = dict([(i, self.quote(targetstring)) for i, targetstring in six.iteritems(target)])
         else:
-            self.msgstr = quoteforpo(target)
-    target = property(gettarget, settarget)
+            self.msgstr = self.quote(target)
+
+    # Deprecated on 2.3.1
+    @deprecated("Use `target` property instead")
+    def gettarget(self):
+        return self.target
 
     def getalttrans(self):
         """Return a list of alternate units.
@@ -578,7 +622,7 @@ class pounit(pocommon.pounit):
         return len(self.msgid_plural) > 0
 
     def parse(self, src):
-        return poparser.parse_unit(poparser.ParseState(BytesIO(src), pounit), self)
+        return poparser.parse_unit(poparser.ParseState(splitlines(src), pounit), self)
 
     def _getmsgpartstr(self, partname, partlines, partcomments=""):
         if isinstance(partlines, dict):
@@ -610,7 +654,7 @@ class pounit(pocommon.pounit):
                         comment = comment[:-len("\\n")]
                     #Before we used to strip. Necessary in some cases?
                     combinedcomment.append(comment)
-                partcomments = quoteforpo("_:%s" % "".join(combinedcomment))
+                partcomments = self.quote("_:%s" % "".join(combinedcomment))
             # comments first, no blank leader line needed
             partstr += "\n".join(partcomments)
             partstr = quote.rstripeol(partstr)
@@ -697,8 +741,7 @@ class pounit(pocommon.pounit):
 
         """
         location = data.forceunicode(location)
-        if location.find(" ") != -1:
-            location = pocommon.quote_plus(location)
+        location = pocommon.quote_plus(location)
         self.sourcecomments.append("#: %s\n" % location)
 
     def _extract_msgidcomments(self, text=None):
@@ -727,7 +770,7 @@ class pounit(pocommon.pounit):
 
     def setcontext(self, context):
         context = data.forceunicode(context)
-        self.msgctxt = quoteforpo(context)
+        self.msgctxt = self.quote(context)
 
     def getid(self):
         """Returns a unique identifier for this unit."""
@@ -750,17 +793,27 @@ class pofile(pocommon.pofile):
 
     UnitClass = pounit
 
+    def __init__(self, inputfile=None, width=None, **kwargs):
+        self.wrapper = copy.copy(wrapper)
+        if width is not None:
+            self.wrapper.width = width
+        super(pofile, self).__init__(inputfile, **kwargs)
+
+    def create_unit(self):
+        return self.UnitClass(wrapper=self.wrapper)
+
     def parse(self, input):
         """Parses the given file or file source string."""
         if hasattr(input, 'name'):
             self.filename = input.name
         elif not getattr(self, 'filename', ''):
             self.filename = ''
-        if isinstance(input, bytes):
-            input = BytesIO(input)
+        if not isinstance(input, bytes):
+            input = input.read()
+        input = iter(splitlines(input))
         # clear units to get rid of automatically generated headers before parsing
         self.units = []
-        poparser.parse_units(poparser.ParseState(input, pounit), self)
+        poparser.parse_units(poparser.ParseState(input, self.create_unit), self)
 
     def removeduplicates(self, duplicatestyle="merge"):
         """Make sure each msgid is unique ; merge comments etc from
@@ -799,7 +852,7 @@ class pofile(pocommon.pofile):
                     if not thepo.msgctxt == id_dict[id].msgctxt:
                         uniqueunits.append(thepo)
                     else:
-                        logger.warn(
+                        logger.warning(
                             "Duplicate unit found with msgctx of '%s' and source '%s'",
                             thepo.msgctxt,
                             thepo.source)
@@ -857,3 +910,7 @@ class pofile(pocommon.pofile):
         for unit in self.units:
             if not (unit.isheader() or unit.isobsolete()):
                 yield unit
+
+    def addunit(self, unit):
+        unit.wrapper = self.wrapper
+        super(pofile, self).addunit(unit)
