@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-from __future__ import print_function
+from __future__ import print_function, unicode_literals
 
 from lxml import etree
 
@@ -71,6 +71,11 @@ class TestAndroidResourceUnit(test_monolingual.TestMonolingualUnit):
         xml = '<string name="teststring">quote \\\'escape\\\'</string>\n\n'
         self.__check_escape(string, xml)
 
+    def test_escape_question(self):
+        string = 'question?'
+        xml = '<string name="teststring">question\\?</string>\n\n'
+        self.__check_escape(string, xml)
+
     def test_escape_double_space(self):
         string = 'double  space'
         xml = '<string name="teststring">"double  space"</string>\n\n'
@@ -209,6 +214,11 @@ class TestAndroidResourceUnit(test_monolingual.TestMonolingualUnit):
         xml = '<string name="teststring">\\@twitterescape</string>\n\n'
         self.__check_parse(string, xml)
 
+    def test_parse_question(self):
+        string = '?'
+        xml = '<string name="question">\\?</string>'
+        self.__check_parse(string, xml)
+
     def test_parse_quote(self):
         string = 'quote \'escape\''
         xml = '<string name="teststring">quote \\\'escape\\\'</string>\n\n'
